# jamexp

## cli

* `jstar`: star files with fzf prompt.

### `jwdc`: clear stale, short and notag
```shell
export WANDB_ENTITY=name
export WANDB_API_KEY=key
```

* `stale`: [0, 10], [7, 60], [3, 180], [1, 600] (days, run_duration/seconds)
* `short`: three days ago and no tags

### `jhydc`: clear hyd exp folders

* `stale`: [0, 10], [7, 60], [3, 180], [1, 600]
* `wandb-sync`

* `jpin`: pin good results

### `jln` and `junln`
